--------
Geometry
--------
.. module:: stellarmesh


Geometry construction
---------------------

Stellarmesh supports both `build123d <https://github.com/gumyr/build123d>`__ (recommended) and `CadQuery <https://github.com/CadQuery/cadquery>`__ for geometry construction but does not depend on either. See :doc:`../install`.


API
---------------------

.. autosummary::
    :toctree: generated
    :nosignatures:
    :template: class.rst

    Geometry